#!/usr/bin/perl -w

#################################################################
#
#  sd_path_restore.pl
#
#  Author: Don Porter <porterde@mercury.hendrix.edu>
#
#  restores missing sd_path entries into .pvfsdir files.  This is
#  caused by the proposed patch to drop these from the dmeta.
#  Basically, this util lets you back out of the patch.
#
##################################################################

use strict;
use warnings;

#make sure an argument is there
unless(defined $ARGV[0]){
    usage();
}

my $root_path = $ARGV[0];

#drop trailing slash from root path
$root_path =~ s|/$||;

check_directory($root_path);

sub check_directory {
    my $path = shift;
#    print "Check directory called for $path\n";

    # check .pvfsdir 
    check_pvfsdir($path);
    
    # recursively check all subdirectories
    my $ent;
    foreach my $ent (<${path}/*>){
	if(-d "$ent"){
	    check_directory($ent);
	}
    }
}

sub check_pvfsdir {
    my $path = shift;
    #drop trailing slash from path
    $path =~ s/\/$//;
    my @pvfsdir;
    open IN, "$path/.pvfsdir";
    @pvfsdir = <IN>;
    close IN;
    unless(defined $pvfsdir[7]){
#	print "Caught $path/.pvfsdir\n";
	if($path eq $root_path){
	    $pvfsdir[7] = "/\n";
	} else {
	    $path =~ /$root_path\/(.*)\/?$/;
	    $pvfsdir[7] = "$1\n\n";
	}
    }
    open OUT, ">$path/.pvfsdir";
    print OUT @pvfsdir;
    close OUT;
}

sub usage {
    print STDERR "Usage: sd_path_restore.pl <pvfs metadata root directory>\n";
    exit;
}
